@@ -53,6 +53,39 @@ __MERCHANT_REGISTERED_CUSTOMER_SCHEMA = {
                             bigquery.SchemaField('UpdatedDateTime', 'DATETIME'),
                             }
 
+__MERCHANT_CUSTOMER_TRANSACTION_SCHEMA = {
+                        
+                            #customer key
+                            bigquery.SchemaField('Key', 'STRING'),
+                            bigquery.SchemaField('UserKey', 'STRING'),
+                            bigquery.SchemaField('CustomerKey', 'STRING'),
+                            bigquery.SchemaField('MerchantKey', 'STRING'),
+                            bigquery.SchemaField('TransactOutlet', 'STRING'),
+                            bigquery.SchemaField('TransactionId', 'STRING'),
+                            bigquery.SchemaField('InvoiceId', 'STRING'),
+                            bigquery.SchemaField('TransactAmount', 'FLOAT64'),
+                            bigquery.SchemaField('TransactDateTime', 'DATETIME'),
+                            bigquery.SchemaField('UpdatedDateTime', 'DATETIME'),
+                            }
+
+__MERCHANT_CUSTOMER_REWARD_SCHEMA = {
+                        
+                            #customer key
+                            bigquery.SchemaField('Key', 'STRING'),
+                            bigquery.SchemaField('CustomerKey', 'STRING'),
+                            bigquery.SchemaField('MerchantKey', 'STRING'),
+                            bigquery.SchemaField('TransactOutlet', 'STRING'),
+                            bigquery.SchemaField('TransactionId', 'STRING'),
+                            bigquery.SchemaField('TransactAmount', 'FLOAT64'),
+                            bigquery.SchemaField('TransactDateTime', 'DATETIME'),
+                            bigquery.SchemaField('RewardFormat', 'STRING'),
+                            bigquery.SchemaField('RewardAmount', 'FLOAT64'),
+                            bigquery.SchemaField('ExpiryDate', 'DATETIME'),
+                            bigquery.SchemaField('RewardFormatKey', 'STRING'),
+                            bigquery.SchemaField('RewardedDateTime', 'DATETIME'),
+                            bigquery.SchemaField('UpdatedDateTime', 'DATETIME'),
+                            }
+
 __REGISTERED_MERCHANT_SCHEMA = {
                         
                             #customer key
@@ -66,13 +99,17 @@ __REGISTERED_MERCHANT_SCHEMA = {
 
 REGISTERED_USER_TEMPLATE                    = 'registered_user'
 REGISTERED_CUSTOMER_TEMPLATE                = 'registered_customer'
+CUSTOMER_TRANSACTION_TEMPLATE               = 'customer_transaction'
 REGISTERED_MERCHANT_TEMPLATE                = 'registered_merchant'
 MERCHANT_REGISTERED_CUSTOMER_TEMPLATE       = 'merchant_registered_customer'
+MERCHANT_CUSTOMER_REWARD_TEMPLATE           = 'customer_reward'
     
 
 TABLE_SCHEME_TEMPLATE = {
-                    REGISTERED_USER_TEMPLATE                :  __REGISTERED_USER_SCHEMA,
-                    REGISTERED_CUSTOMER_TEMPLATE            :  __REGISTERED_CUSTOMER_SCHEMA,
-                    REGISTERED_MERCHANT_TEMPLATE            :  __REGISTERED_MERCHANT_SCHEMA,
+                    REGISTERED_USER_TEMPLATE                : __REGISTERED_USER_SCHEMA,
+                    REGISTERED_CUSTOMER_TEMPLATE            : __REGISTERED_CUSTOMER_SCHEMA,
+                    REGISTERED_MERCHANT_TEMPLATE            : __REGISTERED_MERCHANT_SCHEMA,
                     MERCHANT_REGISTERED_CUSTOMER_TEMPLATE   : __MERCHANT_REGISTERED_CUSTOMER_SCHEMA,
+                    CUSTOMER_TRANSACTION_TEMPLATE           : __MERCHANT_CUSTOMER_TRANSACTION_SCHEMA,
+                    MERCHANT_CUSTOMER_REWARD_TEMPLATE       : __MERCHANT_CUSTOMER_REWARD_SCHEMA
     }
