@@ -64,7 +64,7 @@ __CUSTOMER_REWARD_DATA_TEMPLATE_UPSTREAM_SCHEMA = {
                                             "TransactDateTime"      : 'transact_datetime',
                                             "RewardFormat"          : 'reward_format',
                                             "RewardAmount"          : 'reward_amount',
-                                            "ExpiryDate"            : 'reward_amount',
+                                            "ExpiryDate"            : 'expiry_date',
                                             "RewardFormatKey"       : 'reward_format_key',
                                             "RewardedDateTime"      : 'rewarded_datetime',
                                             }
