@@ -5,23 +5,23 @@ Created on 18 Sep 2020
 '''
 import logging, os, config_path
 
-APPLICATION_NAME                            = 'Trex Analytics'
-APPLICATION_TITLE                           = 'Trex Analytics Platform'
-APPLICATION_DESC                            = 'Trex Analytics is used to anlayze data project'
-APPLICATION_HREF                            = 'http://localhost.com:8084/'
+APPLICATION_NAME                                    = 'Trex Analytics'
+APPLICATION_TITLE                                   = 'Trex Analytics Platform'
+APPLICATION_DESC                                    = 'Trex Analytics is used to anlayze data project'
+APPLICATION_HREF                                    = 'http://localhost.com:8084/'
 
-PRODUCTION_MODE                             = "PROD"
-DEMO_MODE                                   = "DEMO"
-LOCAL_MODE                                  = "LOCAL"
+PRODUCTION_MODE                                     = "PROD"
+DEMO_MODE                                           = "DEMO"
+LOCAL_MODE                                          = "LOCAL"
 
 
-#DEPLOYMENT_MODE                     = PRODUCTION_MODE
-DEPLOYMENT_MODE                     = DEMO_MODE
-#DEPLOYMENT_MODE                     = LOCAL_MODE
+#DEPLOYMENT_MODE                                     = PRODUCTION_MODE
+DEPLOYMENT_MODE                                     = DEMO_MODE
+#DEPLOYMENT_MODE                                     = LOCAL_MODE
 
-#DEPLOYMENT_MODE                             = PRODUCTION_MODE
-#DEPLOYMENT_MODE                             = DEMO_MODE
-DEPLOYMENT_MODE                             = LOCAL_MODE
+#DEPLOYMENT_MODE                                     = PRODUCTION_MODE
+#DEPLOYMENT_MODE                                     = DEMO_MODE
+DEPLOYMENT_MODE                                     = LOCAL_MODE
 
 
 CSRF_ENABLED                                        = True
@@ -49,7 +49,7 @@ SUPERUSER_HASHED_PASSWORD                           = os.environ.get('SUPERUSER_
 BIGQUERY_GCLOUD_PROJECT_ID                          = os.environ.get('BIGQUERY_GCLOUD_PROJECT_ID')
 BIGQUERY_SERVICE_ACCOUNT_KEY_FILEPATH               = os.environ['BIGQUERY_SERVICE_ACCOUNT_KEY']
 BIGQUERY_SERVICE_CREDENTIAL_PATH                    = os.path.abspath(os.path.dirname(config_path.__file__)) +'/'+ BIGQUERY_SERVICE_ACCOUNT_KEY_FILEPATH
-
+BIGQUERY_GCLOUD_LOCATION                            = os.environ.get('BIGQUERY_GCLOUD_LOCATION')
 
 ANALYTICS_BASE_URL                                  = os.environ.get('ANALYTICS_BASE_URL')
 UPSTREAM_BASE_URL                                   = os.environ.get('UPSTREAM_BASE_URL')
@@ -60,6 +60,14 @@ STREAM_DATA_PAGE_SIZE                               = 100
 SYSTEM_DATASET                                      = os.environ.get('SYSTEM_DATASET')
 MERCHANT_DATASET                                    = os.environ.get('MERCHANT_DATASET')
 
+ANALYTICS_TASK_GCLOUD_PROJECT_ID                    = os.environ.get('ANALYTICS_TASK_GCLOUD_PROJECT_ID')
+ANALYTICS_TASK_GCLOUD_LOCATION                      = os.environ.get('ANALYTICS_TASK_GCLOUD_LOCATION')
+ANALYTICS_TASK_SERVICE_ACCOUNT_KEY_FILEPATH         = os.environ.get('ANALYTICS_TASK_SERVICE_ACCOUNT_KEY')
+ANALYTICS_TASK_SERVICE_CREDENTIAL_PATH              = os.path.abspath(os.path.dirname(config_path.__file__)) + '/' + ANALYTICS_TASK_SERVICE_ACCOUNT_KEY_FILEPATH
+ANALYTICS_TASK_SERVICE_ACCOUNT_EMAIL                = os.environ.get('ANALYTICS_TASK_SERVICE_ACCOUNT_EMAIL')
+
+
+
 UPSTREAM_UPDATED_DATETIME_FIELD_NAME                = 'UpdatedDateTime'
 
 if DEPLOYMENT_MODE==PRODUCTION_MODE:
