@@ -26,7 +26,7 @@ import_customer_data_bp = Blueprint('import_customer_data_bp', __name__,
                      static_folder='static',
                      url_prefix='/import-customer-data')
 
-logger = logging.getLogger('analytic')
+logger = logging.getLogger('import')
 
 import_customer_data_api = Api(import_customer_data_bp)
 
